<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO; 
use Teknisa\MAN\Services;
use Teknisa\MAN\Services\RelRelacaoCuponsSatService;
use Teknisa\MAN\Utilities;

class RelRelacaoCuponsSat extends CrudWithParameterBag {
    
    protected $dataSourceName = 'vnd4120Y_relRelacaoCuponsSat';
    protected $parameterBagColumns = array('IDTPAMBNFCE', 'IDSITUVENDA', 'CDFILIAL', 'CDCAIXA', 'DTVENDAINI', 'DTVENDAFIN', 'NRORG', 'IDSTATUSNFCE', 'IDMODOPERACNFCE', 'NRINSCRCONS', 'TCDCAIXA', 'IDXMLSATTRANS', 'TIDXMLSATTRANS','TCDFILIAL', 'TDTABERCAIX', 'DTABERCAIX');
    protected $utilService;
    protected $relacaoCuponsSatService;
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Utilities\Util $utilService, RelRelacaoCuponsSatService $relacaoCuponsSatService) {
        $this->utilService = $utilService;
        parent::__construct($dataSourceManager, $parameterBag);
        $this->relacaoCuponsSatService = $relacaoCuponsSatService;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        ini_set('memory_limit', '1G');
        set_time_limit(120);
        $conditions = $this->utilService->getParamsAsArray($request);
        if( array_key_exists('CDFILIAL', $conditions) || array_key_exists('IDSTATUSNFCE', $conditions) || array_key_exists('IDSITUVENDA', $conditions) || array_key_exists('IDMODOPERACNFCE', $conditions)) {
            
            $conditions['CDFILIAL'] = implode($conditions['CDFILIAL'], '_');
            
            if( array_key_exists('NMFILIAL', $conditions) ) {
                unset($conditions['NMFILIAL']);
            }
           
            if( !array_key_exists('IDTPAMBNFCE', $conditions) ) {
                $conditions['IDTPAMBNFCE'] = null;
            }
            if( !array_key_exists('CDCAIXA', $conditions) ) {
                $conditions['CDCAIXA'] = null;
            }
            
            if( array_key_exists('DTVENDA', $conditions) ) {
                $conditions['DTVENDAINI'] = $conditions['DTVENDA'][0];
                $conditions['DTVENDAFIN'] = $conditions['DTVENDA'][1];
                
                unset($conditions['DTVENDA']);
            }
            if( array_key_exists('CDFILICAIXA', $conditions) && $conditions['CDFILICAIXA']  ) {
                $conditions['CDCAIXA'] = implode($conditions['CDFILICAIXA'], '_');
                
                $conditions['TCDCAIXA'] = 'F';
                unset($conditions['CDFILICAIXA']);
            }  else {
                $conditions['CDCAIXA'] = null;
                $conditions['TCDCAIXA'] = 'T';    
            }
            
            if( array_key_exists('DTABERCAIX', $conditions) && $conditions['DTABERCAIX']  ) {
                $conditions['DTABERCAIX'] = implode($conditions['DTABERCAIX'], '_');
                
                $conditions['TDTABERCAIX'] = 'F';
            }  else {
                $conditions['DTABERCAIX'] = null;
                $conditions['TDTABERCAIX'] = 'T';    
            }
            
            $conditions['NRINSCRCONS'] = ( array_key_exists('NRINSCRCONS', $conditions)) ? $conditions['NRINSCRCONS'] : 'T' ;
            
            $conditions['IDSITUVENDA'] = count($conditions['IDSITUVENDA']) > 1 ? 'T' : $conditions['IDSITUVENDA'][0] ;
            
            if(!empty($conditions['IDSTATUSNFCE'])) {
                $conditions['IDXMLSATTRANS'] = implode($conditions['IDSTATUSNFCE'], '_');
                $conditions['TIDXMLSATTRANS'] = null;
            } else {
                $conditions['IDXMLSATTRANS'] = null;
                $conditions['TIDXMLSATTRANS'] = 'T';
            }
            $conditions['IDSTATUSNFCE'] = implode($conditions['IDSTATUSNFCE'], '_');
            
            $conditions['IDMODOPERACNFCE'] = count($conditions['IDMODOPERACNFCE']) > 1 ? 'T' : $conditions['IDMODOPERACNFCE'][0] ;
        } 
            $dataSourceFilter = array();
            
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"=> "=",
                    "value"=> $value
                );
            }
            $original = $request->getFilterCriteria()->getConditions();
                
            for($i = 0 ; $i < count($dataSourceFilter) ; $i++) {
                for($j = 0 ; $j < count($original) ; $j++ ) {
                    if( $dataSourceFilter[$i]['columnName'] === $original[$j]['columnName'] &&
                        $dataSourceFilter[$i]['operator'] !== $original[$j]['operator'])  {
                        $dataSourceFilter[$i]['operator'] = $original[$j]['operator'];
                    }
                    
                }
            }
            $newRequest = new DTO\Request\Filter(
                new FilterCriteria(
                    $request->getFilterCriteria()->getDataSourceName(),
                    $dataSourceFilter,
                    $request->getFilterCriteria()->getPage(),
                    $request->getFilterCriteria()->getPageSize()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            parent::find($newRequest, $response);
            
        
        
        
    }
    
    public function findProdutosVendidos(DTO\Request\Filter $request, DTO\Response $response){
        
        $conditions = $this->utilService->getParamsAsArray($request);
        $response->addDataSet(new DataSet("vnd4120Y_prodVendidos_relRelacaoCuponsSat", $this->relacaoCuponsSatService->find($conditions)));
        
        return $response;
    }
    
}